@@ -17,7 +17,7 @@ import os, datetime
 import hashlib
 from collections import deque
 
-VERSION = "1.0.0"
+VERSION = "1.1.0"
 
 ###############################################################
 class idict(object):
@@ -367,6 +367,10 @@ class iterator(object):
     else:
       self.ldict.remove( self.dag.nodes[item] )
   
+  def __len__(self):
+    """Returns number of all items currently available in iterator ('remove' reduces this value)."""
+    return len(self.ldict.dict)
+    
 ###########################################################
 class dagger(object):
   def __init__(self, hashfile='', sqlite=False, sqlite_memory=1):
